@@ -446,6 +446,7 @@ simulateCrossResCovRCS_Group <- function(corrected,
   intTermIsRCS <- vapply(elemsInIntTerms, FUN.VALUE = logical(1L),
                          FUN = \(elems) all(elems %in% constructs))
   elemsInIntTerms <- elemsInIntTerms[intTermIsRCS]
+  intTerms <- intTerms[intTermIsRCS]
 
   if (!length(elemsInIntTerms))
     return(EMPTY)
@@ -471,35 +472,19 @@ simulateCrossResCovRCS_Group <- function(corrected,
     colnames(RESIDUALS)  <- single.items[nm]
   } else RESIDUALS <- list()
 
-  getres <- function(y, x) {
-    missing <- is.na(y) | is.na(x)
-
-    x.c <- x[!missing]
-    y.c <- y[!missing]
-
-    epsilon <- stats::residuals(stats::lm(x.c ~ y.c))
-
-    out <- rep(NA, length(epsilon))
-    out[!missing] <- epsilon
-
-    out
-  }
-
   for (intTerm in intTerms) {
     elems  <- elemsInIntTerms[[intTerm]]
     items  <- single.items[elems]
     nameXZ <- paste0(items, collapse = "")
 
-    xz.construct <- apply(CONSTRUCTS[elems], MARGIN = 1, FUN = prod)
-    xz.item      <- apply(ITEMS[items],  MARGIN = 1, FUN = prod)
-    xz.residual  <- getres(y = xz.item, x = xz.construct)
+    xz.construct <- multiplyIndicatorsCpp(CONSTRUCTS[elems])
+    xz.item      <- multiplyIndicatorsCpp(ITEMS[items])
 
     CONSTRUCTS[[intTerm]] <- xz.construct
-    RESIDUALS[[nameXZ]]   <- xz.residual
-    ITEMS[[intTerm]]      <- xz.item
+    ITEMS[[nameXZ]]      <- xz.item
   }
 
-  Epsilon <- stats::cov(as.data.frame(RESIDUALS), use = "na.or.complete")
+  Epsilon <- stats::cov(ITEMS) - stats::cov(CONSTRUCTS)
   newRows <- NULL
 
   for (i in seq_len(NROW(Epsilon))) {
@@ -508,10 +493,18 @@ simulateCrossResCovRCS_Group <- function(corrected,
       lhs <- rownames(Epsilon)[[i]]
       rhs <- colnames(Epsilon)[[j]]
 
-      matching <- parTable[((parTable$lhs == rhs & parTable$rhs == lhs) |
+      elems.lhs <- stringr::str_split_1(lhs, "composite_")
+      elems.rhs <- stringr::str_split_1(rhs, "composite_")
+
+      elems.lhs <- elems.lhs[elems.lhs != ""]
+      elems.rhs <- elems.rhs[elems.rhs != ""]
+
+      matching <- parTable[((parTable$lhs == lhs & parTable$rhs == rhs) |
                             (parTable$lhs == rhs & parTable$rhs == lhs)) &
                            parTable$op == "~~", ]
-      if (NROW(matching)) next
+
+      if (NROW(matching) || !length(intersect(elems.lhs, elems.rhs)))
+        next
 
       newRows <- rbind(
         newRows,
