@@ -19,7 +19,14 @@ transformedSolutionCOEFS <- function(object,
     coef <- lavaan::coef
   }
 
-  parTable <- parameter_estimates(object, colon.pi = TRUE, high.order.as.measr = FALSE)
+  parTable <- parameter_estimates(
+    object = object,
+    colon.pi = TRUE,
+    high.order.as.measr = FALSE,
+    rm.tmp.ov = FALSE,
+    label.renamed.prod = TRUE
+  )
+
   parTable <- subsetByGrouping(parTable, grouping = grouping) # if NULL no subsetting
 
   if (!"group" %in% names(parTable))
