@@ -11,11 +11,11 @@ m1 <- "
 
 est_m1_lms <- modsem(m1, oneInt, method = "lms", calc.se=FALSE)
 testthat::expect_true(est_m1_lms$iterations == 2L) # lowest possible number of iterations for lms
-testthat::expect_warning(summary(est_m1_lms), "Comparative fit to H0 will not be calculated.")
+testthat::expect_no_condition(summary(est_m1_lms))
 
 est_m1_qml <- modsem(m1, oneInt, method = "qml", calc.se=FALSE)
 testthat::expect_true(est_m1_qml$iterations == 1L) # lowest possible number of iterations for qml
-testthat::expect_warning(summary(est_m1_qml), "Comparative fit to H0 will not be calculated.")
+testthat::expect_no_condition(summary(est_m1_qml))
 
 
 tpb <- "
@@ -36,12 +36,12 @@ tpb <- "
 
 est_tpb_lms <- modsem(tpb, TPB, method = "lms", calc.se=TRUE)
 testthat::expect_true(est_tpb_lms$iterations == 2L)
-testthat::expect_warning(summary(est_tpb_lms), "Comparative fit to H0 will not be calculated.")
+testthat::expect_no_condition(summary(est_tpb_lms))
 print(summary(est_tpb_lms, H0 = FALSE, standardized = TRUE))
 
 est_tpb_qml <- modsem(tpb, TPB, method = "qml", calc.se=FALSE)
 testthat::expect_true(est_tpb_qml$iterations <= 1L)
-testthat::expect_warning(summary(est_tpb_qml), "Comparative fit to H0 will not be calculated.")
+testthat::expect_no_condition(summary(est_tpb_qml))
 
 
 tpb_main <- "
@@ -63,12 +63,12 @@ tpb_cov <- "
 est_split_lms <- modsem(tpb_main, data = TPB, method = "lms",
                            calc.se=FALSE, cov.syntax = tpb_cov)
 testthat::expect_true(est_split_lms$iterations == 2)
-testthat::expect_warning(summary(est_split_lms), "Comparative fit to H0 will not be calculated.")
+testthat::expect_no_condition(summary(est_split_lms))
 
 est_split_qml <- modsem(tpb_main, data = TPB, method = "qml",
                            calc.se=FALSE, cov.syntax = tpb_cov)
 testthat::expect_true(est_split_qml$iterations == 1)
-testthat::expect_warning(summary(est_split_qml), "Comparative fit to H0 will not be calculated.")
+testthat::expect_no_condition(summary(est_split_qml))
 
 
 dupsn1 <- "
@@ -86,11 +86,11 @@ dupsn1 <- "
 
 est_dupsn1_lms <- modsem(dupsn1, TPB, method = "lms", calc.se=FALSE)
 testthat::expect_true(est_dupsn1_lms$iterations == 2)
-testthat::expect_warning(summary(est_tpb_lms), "Comparative fit to H0 will not be calculated.")
+testthat::expect_no_condition(summary(est_tpb_lms))
 
 est_dupsn1_qml <- modsem(dupsn1, TPB, method = "qml", calc.se=FALSE)
 testthat::expect_true(est_dupsn1_qml$iterations == 1)
-testthat::expect_warning(summary(est_tpb_qml), "Comparative fit to H0 will not be calculated.")
+testthat::expect_no_condition(summary(est_tpb_qml))
 
 
 tpb <- '
